==> verttice_ui-0.1.5.tar.gz: lib/src/widgets/themed_widgets/themed_setter_button.dart <==
// 🐦 Flutter imports:
import 'package:flutter/material.dart';
import 'package:verttice_ui/src/providers/verttice_ui_prefrence_provider.dart';

// 📦 Package imports:

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

List<Map<String, Color>> accentColorNames = [
  {'orange': Colors.orange},
  {'red': Colors.red},
  {'cyan': Colors.cyan},
  {'purple': Colors.purple},
  {'blue': Colors.blue},
  {'teal': Colors.teal},
  {'green': Colors.green},
];

class ThemedSetterButton extends StatelessWidget {
  const ThemedSetterButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer(builder: (context, ref, child) {
      VertticeUIPreference vertticeUIPreference = ref.watch(
        vertticeUIPreferenceProvider,
      );

      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          const Text('Select Accent Color', style: TextStyle(fontSize: 12)),
          sizedBoxH8,
          Wrap(
            children: List.generate(accentColorNames.length, (index) {
              final color = accentColorNames[index].values.first;
              return Tooltip(
                message: accentColorNames[index].keys.first,
                child: _buildColorBlock(
                    currentColorName:
                        vertticeUIPreference.themedColors.accentColorName,
                    color: color,
                    colorName: accentColorNames[index].keys.first,
                    onColorChanged: (colorName) async {
                      await ref
                          .read(vertticeUIPreferenceProvider.notifier)
                          .setThemedColors(colorName);
                    }),
              );
            }),
          ),
        ],
      );
    });
  }

  Widget _buildColorBlock({
    required String currentColorName,
    required Color color,
    required String colorName,
    required void Function(String colorName) onColorChanged,
  }) {
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: ElevatedButton(
        onPressed: () {
          onColorChanged(colorName);
        },
        style: ButtonStyle(
          padding: MaterialStateProperty.all(EdgeInsets.zero),
          backgroundColor: MaterialStateProperty.resolveWith((states) {
            return color;
          }),
        ),
        child: Container(
          height: 40,
          width: 40,
          alignment: Alignment.center,
          child: currentColorName == colorName
              ? const Icon(
                  Icons.check,
                  color: Colors.black,
                  size: 22.0,
                )
              : null,
        ),
      ),
    );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/themed_widgets/themed_setter_button.dart <==
// 🐦 Flutter imports:
import 'package:flutter/material.dart';
import 'package:verttice_ui/src/providers/verttice_ui_prefrence_provider.dart';

// 📦 Package imports:

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

List<Map<ThemedColor, Color>> accentColorNames = [
  {ThemedColor.orange: Colors.orange},
  {ThemedColor.red: Colors.red},
  {ThemedColor.cyan: Colors.cyan},
  {ThemedColor.purple: Colors.purple},
  {ThemedColor.blue: Colors.blue},
  {ThemedColor.teal: Colors.teal},
  {ThemedColor.green: Colors.green},
];

class ThemedSetterButton extends StatelessWidget {
  const ThemedSetterButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer(builder: (context, ref, child) {
      VertticeUIPreference vertticeUIPreference = ref.watch(
        vertticeUIPreferenceProvider,
      );

      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          const Text('Select Accent Color', style: TextStyle(fontSize: 12)),
          sizedBoxH8,
          Wrap(
            children: List.generate(accentColorNames.length, (index) {
              final color = accentColorNames[index].values.first;
              return Tooltip(
                message: accentColorNames[index].keys.first.name,
                child: _buildColorBlock(
                    currentColorName:
                        vertticeUIPreference.themedColors.accentColorName,
                    color: color,
                    colorName: accentColorNames[index].keys.first,
                    onColorChanged: (colorName) async {
                      await ref
                          .read(vertticeUIPreferenceProvider.notifier)
                          .setThemedColors(colorName);
                    }),
              );
            }),
          ),
        ],
      );
    });
  }

  Widget _buildColorBlock({
    required ThemedColor currentColorName,
    required Color color,
    required ThemedColor colorName,
    required void Function(ThemedColor colorName) onColorChanged,
  }) {
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: ElevatedButton(
        onPressed: () {
          onColorChanged(colorName);
        },
        style: ButtonStyle(
          padding: MaterialStateProperty.all(EdgeInsets.zero),
          backgroundColor: MaterialStateProperty.resolveWith((states) {
            return color;
          }),
        ),
        child: Container(
          height: 40,
          width: 40,
          alignment: Alignment.center,
          child: currentColorName == colorName
              ? const Icon(
                  Icons.check,
                  color: Colors.black,
                  size: 22.0,
                )
              : null,
        ),
      ),
    );
  }
}
